@@ -36,6 +36,8 @@ Usage:
     %(cmd)s motherboard
     %(cmd)s cpu
     %(cmd)s memory
+    %(cmd)s pci
+    %(cmd)s disks
 
 Commands:
     all          Display all available information.
@@ -43,6 +45,8 @@ Commands:
     motherboard  Display motherboard information.
     cpu          Display processor information.
     memory       Display memory information.
+    pci          Display PCI devices information.
+    disks        Display disks information.
 """
 
 from lmi.scripts.common import command
@@ -65,6 +69,12 @@ class Cpu(HwBase):
 class Memory(HwBase):
     CALLABLE = 'lmi.scripts.hardware:get_memory_info'
 
+class PCI(HwBase):
+    CALLABLE = 'lmi.scripts.hardware:get_pci_info'
+
+class Disks(HwBase):
+    CALLABLE = 'lmi.scripts.hardware:get_disks_info'
+
 Hardware = command.register_subcommands(
         'Hardware', __doc__,
         { 'all'          : All
@@ -72,6 +82,8 @@ Hardware = command.register_subcommands(
         , 'motherboard'  : Motherboard
         , 'cpu'          : Cpu
         , 'memory'       : Memory
+        , 'pci'          : PCI
+        , 'disks'        : Disks
         },
         fallback_command=All
     )
